@@ -10,3 +10,7 @@ with open(path.join(here, 'VERSION')) as f:
 from .dataset import Dataset
 from .datatype import Data, ChanTime, ChanFreq, ChanTimeFreq
 from .graphoelement import Graphoelement
+try:
+    from .bin.scroll_data import MainWindow as Wonambi
+except ImportError:  # PyQt is not installed
+    Wonambi = None
