@@ -2,10 +2,11 @@
 """
 from copy import deepcopy
 from logging import getLogger
-from warnings import warn
+from functools import partial
+from multiprocessing import Pool
 
-from numpy import (arange, array, asarray, copy, empty, exp, log, max, mean, 
-                   median, pi, real, sqrt, swapaxes, zeros)
+from numpy import (arange, array, asarray, copy, empty, exp, log, max, mean,
+                   median, moveaxis, pi, real, reshape, sqrt, swapaxes, zeros)
 from numpy.linalg import norm
 import numpy.fft as np_fft
 from scipy import fftpack
@@ -96,16 +97,15 @@ def frequency(data, output='spectraldensity', scaling='power', sides='one',
 
     It uses sampling frequency as specified in s_freq, it does not
     recompute the sampling frequency based on the time axis.
-    
-    Use of log or median for Welch's method is included based on 
+
+    Use of log or median for Welch's method is included based on
     recommendations from Izhikevich et al., bioRxiv, 2018.
     """
     if output not in ('spectraldensity', 'complex', 'csd'):
         raise TypeError(f'output can be "spectraldensity", "complex" or "csd",'
                         ' not "{output}"')
     if 'time' not in data.list_of_axes:
-        raise TypeError('\'time\' is not in the axis ' +
-                        str(data.list_of_axes))
+        raise TypeError('\'time\' is not in the axis ' + str(data.list_of_axes))
     if len(data.list_of_axes) != data.index_of('time') + 1:
         raise TypeError('\'time\' should be the last axis')  # this might be improved
 
@@ -150,7 +150,7 @@ def frequency(data, output='spectraldensity', scaling='power', sides='one',
 
         if log_trans:
             Sxx = log(Sxx)
-        
+
         if duration is not None:
             if centend == 'mean':
                 Sxx = Sxx.mean(axis=-2)
@@ -171,7 +171,7 @@ def frequency(data, output='spectraldensity', scaling='power', sides='one',
     return freq
 
 
-def timefrequency(data, method='morlet', time_skip=1, **options):
+def timefrequency(data, method='morlet', **options):
     """Compute the power spectrum over time.
 
     Parameters
@@ -223,9 +223,6 @@ def timefrequency(data, method='morlet', time_skip=1, **options):
         dur_in_s : float
             total duration of the wavelet, two-sided (i.e. from start to
             finish)
-        time_skip : int, in samples
-            number of time points to skip (it runs convolution on all the
-            data points, but you don't need to store them all)
         normalization : str
             'area' means that energy is normalized to 1, 'peak' means that the
             peak of the wavelet is set at 1, 'max' is a normalization used by
@@ -287,26 +284,33 @@ def timefrequency(data, method='morlet', time_skip=1, **options):
 
     if method == 'morlet':
 
+        # we assume that the data is ChanTime
+        assert data.index_of('chan') == 0
+        assert data.index_of('time') == 1
+
         wavelets = _create_morlet(deepcopy(options), data.s_freq)
 
         for i in range(data.number_of('trial')):
             lg.info('Processing trial # {0: 6}'.format(i))
             timefreq.axis['freq'][i] = array(options['foi'])
-            timefreq.axis['time'][i] = data.axis['time'][i][::time_skip]
+            timefreq.axis['time'][i] = data.axis['time'][i]
 
             timefreq.data[i] = empty((data.number_of('chan')[i],
-                                      data.number_of('time')[i] // time_skip,
+                                      data.number_of('time')[i],
                                       len(options['foi'])),
                                      dtype='complex')
-            for i_c, chan in enumerate(data.axis['chan'][i]):
-                dat = data(trial=i, chan=chan)
-                for i_f, wavelet in enumerate(wavelets):
-                    tf = fftconvolve(dat, wavelet, 'same')
-                    timefreq.data[i][i_c, :, i_f] = tf[::time_skip]
 
-        if time_skip != 1:
-            warn('sampling frequency in s_freq refers to the input data, '
-                 'not to the timefrequency output')
+            data_i = data(trial=i)
+            args = []
+            for i_chan in range(data.number_of('chan')[i]):
+                for wavelet in wavelets:
+                    args.append((i_chan, wavelet))
+
+            with Pool() as p:
+                result = p.starmap(partial(_convolve, dat=data_i), args)
+
+            tf = reshape(array(result), (data.number_of('chan')[i], len(wavelets), -1))
+            timefreq.data[i] = moveaxis(tf, 2, 1)
 
     elif method in ('spectrogram', 'stft'):  # TODO: add timeskip
         nperseg = int(options['duration'] * data.s_freq)
@@ -346,7 +350,7 @@ def timefrequency(data, method='morlet', time_skip=1, **options):
 def band_power(data, freq, scaling='power', n_fft=None, detrend=None,
                array_out=False):
     """Compute power or energy acoss a frequency band, and its peak frequency.
-    Power is estimated using the mid-point rectangle rule. Input can be 
+    Power is estimated using the mid-point rectangle rule. Input can be
     ChanTime or ChanFreq.
 
     Parameters
@@ -355,14 +359,14 @@ def band_power(data, freq, scaling='power', n_fft=None, detrend=None,
         data to be analyzed, one trial only
     freq : tuple of float
         Frequencies for band of interest. Power will be integrated across this
-        band, inclusively, and peak frequency determined within it. If a value 
+        band, inclusively, and peak frequency determined within it. If a value
         is None, the band is unbounded in that direction.
     input_type : str
         'time' or 'spectrum'
     scaling : str
         'power' or 'energy', only used if data is ChanTime
     n_fft : int
-        length of FFT. if shorter than input signal, signal is truncated; if 
+        length of FFT. if shorter than input signal, signal is truncated; if
         longer, signal is zero-padded to length
     array_out : bool
         if True, will return two arrays instead of two dict.
@@ -387,23 +391,23 @@ def band_power(data, freq, scaling='power', n_fft=None, detrend=None,
         Sxx = frequency(data, scaling=scaling, n_fft=n_fft, detrend=detrend)
     else:
         raise ValueError('Invalid data type')
-    
+
     if detrend is None:
         if 'power' == scaling:
             detrend = 'linear'
         elif 'energy' == scaling:
             detrend = None
-    
+
     sf = Sxx.axis['freq'][0]
-    f_res = sf[1] - sf[0] # frequency resolution
-    
+    f_res = sf[1] - sf[0]  # frequency resolution
+
     if freq[0] is not None:
         idx_f1 = asarray([abs(x - freq[0]) for x in sf]).argmin()
     else:
         idx_f1 = 0
     if freq[1] is not None:
         idx_f2 = min(asarray([abs(x - freq[1]) for x in sf]).argmin() + 1,
-                     len(sf) - 1) # inclusive, to follow convention
+                     len(sf) - 1)  # inclusive, to follow convention
     else:
         idx_f2 = len(sf) - 1
 
@@ -413,7 +417,7 @@ def band_power(data, freq, scaling='power', n_fft=None, detrend=None,
 
         idx_peak = s[idx_f1:idx_f2].argmax()
         pf = sf[idx_f1:idx_f2][idx_peak]
-        
+
         if array_out:
             power[i, 0] = pw
             peakf[i, 0] = pf
@@ -451,7 +455,7 @@ def _create_morlet(options, s_freq):
 
 
 def morlet(freq, s_freq, ratio=5, sigma_f=None, dur_in_sd=4, dur_in_s=None,
-           normalization='peak', zero_mean=False):
+           normalization='wonambi', zero_mean=False):
     """Create a Morlet wavelet.
 
     Parameters
@@ -470,9 +474,14 @@ def morlet(freq, s_freq, ratio=5, sigma_f=None, dur_in_sd=4, dur_in_s=None,
     dur_in_s : float
         total duration of the wavelet, two-sided (i.e. from start to finish)
     normalization : str
-        'area' means that energy is normalized to 1, 'peak' means that the peak
-        is set at 1, 'max' is a normalization used by nitime which does not
-        change max value of output when you change sigma_f.
+        'wonambi' (default) returns an amplitude of 1 in frequency-domain for a
+        sine wave of amplitude 1 in the time-domain;
+        'juniper' returns amplitude which is dependent on sampling frequency;
+        'area' normalizes the area of the Gaussian envelope to be 1;
+        'peak' normalizes the peak of the Gaussian envelope to be 1.
+        Note that the frequency-domain values for 'area' and 'peak' will
+        depend on the carrier frequency of the wavelet (they depend on sigma_f).
+
     zero_mean : bool
         make sure that the wavelet has zero mean (only relevant if ratio < 5)
 
@@ -497,7 +506,7 @@ def morlet(freq, s_freq, ratio=5, sigma_f=None, dur_in_sd=4, dur_in_s=None,
         sigma_f = freq / ratio
     else:
         ratio = freq / sigma_f
-    sigma_t = 1 / (2 * pi * sigma_f)
+    sigma_t = 1 / sigma_f
 
     if ratio < 5 and not zero_mean:
         lg.info('The wavelet won\'t have zero mean, set zero_mean=True to '
@@ -514,10 +523,12 @@ def morlet(freq, s_freq, ratio=5, sigma_f=None, dur_in_sd=4, dur_in_s=None,
 
     w *= exp(-t ** 2 / (2 * sigma_t ** 2))
 
-    if normalization == 'area':
+    if normalization == 'wonambi':
+        w /= sqrt(pi / 2) * sigma_t * s_freq
+    elif normalization == 'juniper':
+        w /= sqrt(2 * pi) * sigma_t
+    elif normalization == 'area':
         w /= sqrt(sqrt(pi) * sigma_t * s_freq)
-    elif normalization == 'max':
-        w /= 2 * sigma_t * sqrt(2 * pi) / s_freq
     elif normalization == 'peak':
         pass
 
@@ -676,8 +687,8 @@ def _fft(x, s_freq, detrend='linear', taper=None, output='spectraldensity',
     elif output == 'csd':
         result = (result[None, 0, ...].conj() * result[None, 1, ...])
 
-    if (sides == 'one' and output in ('spectraldensity', 'csd') and \
-        scaling != 'chronux'):
+    if (sides == 'one' and output in ('spectraldensity', 'csd')
+       and scaling != 'chronux'):
         if n_fft % 2:
             result[..., 1:] *= 2
         else:
@@ -707,3 +718,8 @@ def _fft(x, s_freq, detrend='linear', taper=None, output='spectraldensity',
         result = swapaxes(result, axis, -1)
 
     return freqs, result
+
+
+def _convolve(i_chan, wavelet, dat):
+    tf = fftconvolve(dat[i_chan, :], wavelet, 'same')
+    return tf
