@@ -3,7 +3,5 @@
     - simulate (functions to create fake data, channels for testing purposes)
 
 """
-from .exceptions import UnrecognizedFormat
+from .exceptions import UnrecognizedFormat, MissingDependency
 from .simulate import create_data, create_channels
-
-from wonambi.utils.fooof.fit import FOOOF
