@@ -1,5 +1,6 @@
 """Widget to redefine the labels.
 """
+from logging import getLogger
 from pathlib import Path
 from re import split
 
@@ -17,6 +18,8 @@ from PyQt5.QtWidgets import (QAbstractItemView,
                              QWidget
                              )
 
+lg = getLogger(__name__)
+
 
 class Labels(QWidget):
     """
